Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(324)

Unified Diff: media/cdm/key_system_names.h

Issue 1732423002: EME: Remove the concept of a parent key system. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@ks
Patch Set: Add test per review. Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/base/key_systems_unittest.cc ('k') | media/cdm/key_system_names.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/cdm/key_system_names.h
diff --git a/media/cdm/key_system_names.h b/media/cdm/key_system_names.h
index 6c388b98c841313ff789d0cb9c3d315c4bfd3cb9..8b231718fffa89d8620f0751cc68783cd229ebac 100644
--- a/media/cdm/key_system_names.h
+++ b/media/cdm/key_system_names.h
@@ -22,9 +22,9 @@ MEDIA_EXPORT extern const char kExternalClearKey[];
// Returns true if |key_system| is Clear Key, false otherwise.
MEDIA_EXPORT bool IsClearKey(const std::string& key_system);
-// Returns true if |key_system| is (reverse) sub-domain of |parent_key_system|.
-MEDIA_EXPORT bool IsParentKeySystemOf(const std::string& parent_key_system,
- const std::string& key_system);
+// Returns true if |key_system| is (reverse) sub-domain of |base|.
+MEDIA_EXPORT bool IsChildKeySystemOf(const std::string& key_system,
+ const std::string& base);
// Returns true if |key_system| is External Clear Key, false otherwise.
MEDIA_EXPORT bool IsExternalClearKey(const std::string& key_system);
« no previous file with comments | « media/base/key_systems_unittest.cc ('k') | media/cdm/key_system_names.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698